Learn R Programming

MATES (version 0.1)

P_Knear_rank: Compute k-rNNG graph

Description

This function builds penalized K nearest neighbor graphs with rank The output is a list containing the graph and the degree distribution

Usage

P_Knear_rank(M, K = round(nrow(M)^0.8), lambda = 0.3)

Value

A list containing the truncated KNN graph (trun_KNN) and the degree distribution (degree)

Arguments

M

A numeric matrix representing the distance matrix

K

An integer representing the number of neighbors to use

lambda

A numeric representing the penalty parameter

References

Zhu, Y., & Chen, H. (2023). A new robust graph for graph-based methods. arXiv preprint arXiv:2307.15205.