Learn R Programming

MATES (version 0.1)

rank_mats: Compute rank matrix

Description

This function computes the rank matrix based on the specified graph type and number of neighbors.

Usage

rank_mats(S, Dd, gtype, k)

Value

A numeric matrix representing the rank matrix

Arguments

S

A numeric matrix representing the similarity matrix

Dd

A dist object representing the distance matrix

gtype

A character string indicating the graph type to use ("NNG", "MST", or "rNNG")

k

A numeric representing the number of neighbors to use for graph

References

Zhu, Y., & Chen, H. (2023). A new robust graph for graph-based methods. arXiv preprint arXiv:2307.15205.